Index: src/objects.h |
diff --git a/src/objects.h b/src/objects.h |
index 8ab5437fdc129f100099afb652cf7e362b85b916..11b51bff19635998672ae906886ba531cd081573 100644 |
--- a/src/objects.h |
+++ b/src/objects.h |
@@ -4712,7 +4712,6 @@ |
// Size is smi tagged when it is stored. |
static const int kSizeOffset = HeapObject::kHeaderSize; |
static const int kNextOffset = POINTER_SIZE_ALIGN(kSizeOffset + kPointerSize); |
- static const int kSize = kNextOffset + kPointerSize; |
private: |
DISALLOW_IMPLICIT_CONSTRUCTORS(FreeSpace); |
@@ -10468,12 +10467,12 @@ |
static const int kLengthOffset = JSObject::kHeaderSize; |
static const int kSize = kLengthOffset + kPointerSize; |
// 400 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which |
// we do not want to include in objects.h |
// Note that Page::kMaxRegularHeapObjectSize has to be in sync with |
// kInitialMaxFastElementArray which is checked in a DCHECK in heap.cc. |
static const int kInitialMaxFastElementArray = |
- (400 * KB - FixedArray::kHeaderSize - kSize - AllocationMemento::kSize) / |
+ (600 * KB - FixedArray::kHeaderSize - kSize - AllocationMemento::kSize) / |
kPointerSize; |
private: |
@@ -10468,12 +10467,12 @@ |
static const int kLengthOffset = JSObject::kHeaderSize; |
static const int kSize = kLengthOffset + kPointerSize; |
- // 400 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which |
+ // 600 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which |
// we do not want to include in objects.h |
// Note that Page::kMaxRegularHeapObjectSize has to be in sync with |